midiogre.core package
=================

Submodules
----------

midiogre.core.compositions module
-----------------------------

.. automodule:: midiogre.core.compositions
   :members:
   :undoc-members:
   :show-inheritance:

midiogre.core.conversions module
-----------------------------

.. automodule:: midiogre.core.conversions
   :members:
   :undoc-members:
   :show-inheritance:

midiogre.core.transforms\_interface module
-------------------------------------

.. automodule:: midiogre.core.transforms_interface
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
--------------

.. automodule:: midiogre.core
   :members:
   :undoc-members:
   :show-inheritance: 